@@ -11,7 +11,7 @@ use Log::Log4perl qw(:easy);
 use Number::Bytes::Human qw( format_bytes parse_bytes );
 
 # ABSTRACT: Yet Another RESTful-Archive Service
-our $VERSION = '0.83'; # VERSION
+our $VERSION = '0.84'; # VERSION
 
 
 has secret => rand;
@@ -21,13 +21,25 @@ sub startup {
     my $self = shift;
     if ($Mojolicious::VERSION >= 4.0) {
         $self->hook(before_dispatch => sub {
-          my($c) = @_;
-          Mojo::IOLoop->stream($c->tx->connection)->timeout(3000);
+            my($c) = @_;
+            my $stream = Mojo::IOLoop->stream($c->tx->connection);
+            return unless defined $stream;
+            $stream->timeout(3000);
         });
-    } elsif ($Mojolicious::VERSION >= 2.37) {
-        Mojo::IOLoop::Stream->timeout(3000);
+    #} elsif ($Mojolicious::VERSION >= 2.37) {
     } else {
-        Mojo::IOLoop->singleton->connection_timeout(3000);
+        eval { Mojo::IOLoop::Stream->timeout(3000) };
+        if(my $error = $@) {
+            WARN "error trying to set timeout: $@";
+            WARN "Mojolicious version $Mojolicious::VERSION";
+            WARN "Will try Mojo 4.x mode";
+            $self->hook(before_dispatch => sub {
+                my($c) = @_;
+                my $stream = Mojo::IOLoop->stream($c->tx->connection);
+                return unless defined $stream;
+                $stream->timeout(3000);
+            });
+        }
     }
 
     my $max_size = 53687091200;
@@ -75,7 +87,6 @@ sub startup {
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
@@ -84,7 +95,7 @@ Yars - Yet Another RESTful-Archive Service
 
 =head1 VERSION
 
-version 0.83
+version 0.84
 
 =head1 DESCRIPTION
 
@@ -262,3 +273,4 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
