@@ -1,7 +1,7 @@
 package Yars::Tools;
 
 # ABSTRACT: various utility functions dealing with servers, hosts, etc
-our $VERSION = '0.83'; # VERSION
+our $VERSION = '0.84'; # VERSION
 
 
 use Clustericious::Config;
@@ -20,6 +20,7 @@ use JSON::XS;
 use File::stat qw/stat/;
 use Mojo::ByteStream qw/b/;
 use File::HomeDir;
+use File::Spec;
 use strict;
 use warnings;
 
@@ -51,7 +52,7 @@ sub refresh_config {
     }
  }
 our $default_dir = $ENV{HARNESS_ACTIVE}
-  ? File::Temp->newdir( "/tmp/yars.test.$<.XXXXXX" )
+  ? File::Temp->newdir( File::Spec->catdir( File::Spec->tmpdir, "yars.test.$<.XXXXXX" ))
   : File::HomeDir->my_home . "/var/run/yars";
  $StateFile = $config->state_file(default => "$default_dir/state.txt");
  -e $StateFile or do {
@@ -364,8 +365,8 @@ sub b642hex {
 
 1;
 
-__END__
 
+__END__
 =pod
 
 =head1 NAME
@@ -374,7 +375,7 @@ Yars::Tools - various utility functions dealing with servers, hosts, etc
 
 =head1 VERSION
 
-version 0.83
+version 0.84
 
 =head1 DESCRIPTION
 
@@ -502,3 +503,4 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
